@@ -1,13 +1,12 @@
 package Class::Define;
+
 use warnings;
 use strict;
 
-our $VERSION = '0.0302';
-
-require Carp;
+use Carp 'croak';
 
 # Valid option names for define method
-my %VALID_DEFINE_OPTIONS = map {$_ => 1} qw/base mixins methods initialize/;
+my %VALID_DEFINE_OPTIONS = map {$_ => 1} qw/base methods initialize/;
 
 # Define class
 sub define {
@@ -19,12 +18,12 @@ sub define {
     }
     # Define named class
     else {
-        return $self->define_named_class(@_);
+        return $self->define_class(@_);
     }
 }
 
 # Define named class
-sub define_named_class {
+sub define_class {
     my $self = shift;
     
     # Class name
@@ -39,7 +38,8 @@ sub define_named_class {
             $id .= $info || '';
         }
         
-        Carp::croak("Cannot create anoymouse class id") unless $id; # maybe never ocuured.
+        croak "Cannot create anoymouse class id"
+          unless $id; # maybe never ocuured.
         
         # Create anonymous class name
         $class = __PACKAGE__->create_anonymous_class_name($id);
@@ -54,92 +54,52 @@ sub define_named_class {
     
     # Check options
     foreach my $key (keys %$options) {
-        Carp::croak("'$key' is invalid option")
-            unless $VALID_DEFINE_OPTIONS{$key};
+        croak "'$key' is invalid option"
+          unless $VALID_DEFINE_OPTIONS{$key};
     }
     
     # Assign each variable
     my $base_class = $options->{base};
-    my $mixin_classes = $options->{mixins} || [];
-    my $methods = $options->{methods} || {};
+    my $methods    = $options->{methods} || {};
     my $initialize = $options->{initialize};
     
     # Class is valid name?
-    Carp::croak("$class is bad name")
-      unless __PACKAGE__->is_valid_class_name($class);
+    croak "$class is bad name"
+      unless $self->is_valid_class_name($class);
     
     # In case the class is already defined
     return $class if $class->can('isa');
     
     # Base class is valid name?
-    Carp::croak("$base_class is bad name")
-      if $base_class && ! __PACKAGE__->is_valid_class_name($base_class);
-    
-    # Mixins must be array ref
-    Carp::croak("mixins must be array ref")
-      if $mixin_classes && ref $mixin_classes ne 'ARRAY';
-    
-    # Mixin classes are valid name?
-    foreach my $mixin_class (@$mixin_classes) {
-        Carp::croak("$mixin_class is bad name")
-          unless __PACKAGE__->is_valid_class_name($mixin_class);
-    }
+    croak "$base_class is bad name"
+      if $base_class && ! $self->is_valid_class_name($base_class);
     
     # Initialize must be code ref
-    Carp::croak("initialize must be code ref")
+    croak "initialize must be code ref"
       if $initialize && ref $initialize ne 'CODE';
     
-    # Rearrange mixins class to string
-    foreach my $mixin_class (@$mixin_classes) {
-        $mixin_class = "'$mixin_class'";
-    }
-    my $mixin_classes_expression = @$mixin_classes ? join(', ', @$mixin_classes) : '';
-    
     # Source code to define class
     my $code = '';
     $code .=
           qq/package $class;\n/;
     
-    if ($base_class && $mixin_classes_expression) {
+    if ($base_class) {
        $code .=
-          qq/use Object::Simple(base => '$base_class', mixins => [$mixin_classes_expression]);\n/;
-    }
-    elsif ($base_class) {
-        $code .=
-          qq/use Object::Simple(base => '$base_class');\n/;
-    }
-    elsif ($mixin_classes_expression) {
-        $code .=
-          qq/use Object::Simple(mixins => [$mixin_classes_expression]);\n/;
-    }
-    else {
-        $code .=
-          qq/use Object::Simple;\n/;
+          qq/use base '$base_class';\n/
     }
     
     # Execute code to define class
     eval $code;
-    Carp::croak("fail eval $code: $@") if $@; # never ocuured
+    croak "fail eval $code: $@" if $@; # never ocuured
     
     # Define methods
     foreach my $name (keys %$methods) {
         
-        # Define acessor to Object::Simple functions
-        if (ref $methods->{$name} eq 'ARRAY') {
-            my ($code_attribute_type, $code_ref) = @{$methods->{$name}};
-            Object::Simple->resist_accessor_info($class, $name, $code_ref, $code_attribute_type);
-        }
-        
-        # Define method using normarl way
-        else {
-            no strict 'refs';
-            *{"${class}::$name"} = $methods->{$name};
-        }
+        # Define method
+        no strict 'refs';
+        *{"${class}::$name"} = $methods->{$name};
     }
     
-    # Build class
-    Object::Simple->build_class($class);
-    
     # Execute initialize process
     $initialize->($class) if $initialize;
     
@@ -160,14 +120,10 @@ sub is_valid_class_name {
     return $class_name =~ /^(\w+::)*\w+$/ ? 1 : 0;
 }
 
-1;
-
 package Class::Define::AnonymousClass;
+
 use strict;
 use warnings;
-require Carp;
-
-our $VERSION = $Class::Define::VERSION;
 
 our $ANONYMOUS_CLASS_PREFIX = 'Class::Define::AnonymousClass::';
 
@@ -240,9 +196,10 @@ sub unload_anonymous_class {
     @{$class . '::ISA'} = ();
     %{$class . '::'} = ();
     delete ${$ANONYMOUS_CLASS_PREFIX}{$id . '::'};
-    delete $Object::Simple::META->{$class};
 }
 
+package Class::Define;
+
 1;
 
 =head1 NAME
@@ -251,15 +208,19 @@ Class::Define - define class easily and anywhere
 
 =head1 VERSION
 
-Version 0.0302
+Version 0.0401
+
+=cut
+
+our $VERSION = 0.0401;
 
 =head1 SYNOPSIS
 
     use Class::Define;
     
+    # Define class
     Class::Define->define('Magazine', {
         base => 'Book',
-        mixins => ['Cloneable'],
         methods => {
             price => sub { }
         },
@@ -269,7 +230,20 @@ Version 0.0302
     });
     
     my $magazine = Magazine->new;
-
+    
+    # Create anonimouse class
+    my $Magazine =  Class::Define->define({
+        base => 'Book',
+        methods => {
+            price => sub { }
+        },
+        initialize => sub {
+            # some code to 
+        }
+    });
+    
+    my $magazine = $Magazine->new;
+    
 =head1 METHODS
 
 =head2 define
@@ -278,6 +252,10 @@ You can define class easily and anywhere.
 
 Class::Define->define('Book', {
     methods => {
+        new   => sub {
+            my $class = shift;
+            return bless {@_}, $class;
+        }
         title => sub { # some accessor code }
     }
 });
@@ -285,13 +263,17 @@ Class::Define->define('Book', {
 this is equal to
 
     package Book;
+    sub new {
+        my $class = shift;
+        return bless {@_}, $class;
+    }
+    
     sub title { # some code }
 
-You can aslo define class which extend other class or mixin other classes to use Object::Simple abilities.
+You can aslo define class which extend other class.
 
     Class::Define->define('Magazine', {
         base => 'Book',
-        mixins => ['Cloneable'],
         methods => {
             price => sub { # some accessor code }
         },
@@ -304,34 +286,13 @@ You can aslo define class which extend other class or mixin other classes to use
 this is equal to
     
     package Magazine;
-    use Object::Simple(base => 'Book', mixins => ['Cloneable']);
+    use base 'Book';
     
     sub price { #some accessor code }
-    
-    Object::Simple->build_class;
-    
+   
     # do initialize
     print "aaa";
 
-You can define attribute by using Object::Simple
-
-    Class::Define->define('Book', {
-        methods => {
-            title => ['Attr', {default => 'AAA'}],
-            price => ['Attr', {default => 1000}]
-        }
-    }
-
-This is equal to
-
-    package Book;
-    use Object::Simple;
-    
-    sub title : Attr { default => 'AAA' }
-    sub price : Attr { default => 1000 }
-    
-    Object::Simple->build_class;
-
 You can also define anonymous class if you do not write class name.
 
     my $anonymous_class = Class::Define->define({
@@ -345,7 +306,7 @@ You can also define anonymous class if you do not write class name.
     
 =head1 SEE ALSO
 
-L<Object::Simple>, L<Class::MOP>
+L<Class::MOP>
 
 =head1 AUTHOR
 
@@ -360,4 +321,3 @@ under the same terms as Perl itself.
 
 =cut
 
-1; # End of Class::Define
